@@ -667,6 +667,9 @@ def group_or_pair(speaker, action, args, soco_function, use_local_speaker_list):
         error_and_exit("Pairing operations require SoCo v0.20 or greater")
         return False
     speaker2 = get_speaker(args[0], use_local_speaker_list)
+    if not speaker2:
+        error_and_exit("Speaker '{}' not found".format(args[0]))
+        return False
     if speaker == speaker2:
         error_and_exit("Speakers are the same")
         return False
@@ -1886,6 +1889,22 @@ SonosFunction = namedtuple(
 )
 
 
+def get_actions(include_additional=True):
+    action_list = list(actions.keys())
+    if include_additional:
+        additional_commands = [
+            "loop",
+            "loop_until",
+            "loop_for",
+            "loop_to_start",
+            "wait_until",
+            "wait",
+            "wait_for",
+        ]
+        action_list = action_list + additional_commands
+    return sorted(action_list)
+
+
 def list_actions(include_additional=True):
     action_list = list(actions.keys())
     if include_additional:
