@@ -10,6 +10,7 @@ from signal import SIGINT, signal
 import soco
 
 from .action_processor import list_actions, process_action
+from .interactive import interactive_loop
 from .speakers import Speakers
 from .utils import (
     RewindableList,
@@ -33,7 +34,8 @@ pp = pprint.PrettyPrinter(width=100)
 
 
 # Speaker name environment variable
-env_spkr_name = "SPKR"
+ENV_SPKR = "SPKR"
+ENV_LOCAL = "USE_LOCAL"
 
 
 def main():
@@ -123,6 +125,8 @@ def main():
     configure_logging(args.log)
 
     use_local_speaker_list = args.use_local_speaker_list
+    if env.get(ENV_LOCAL) == "TRUE" and not args.no_env:
+        use_local_speaker_list = True
     if use_local_speaker_list:
         speaker_list = Speakers(
             network_threads=args.network_discovery_threads,
@@ -139,7 +143,7 @@ def main():
     env_speaker = None
     if not args.no_env:
         logging.info("Ignoring 'SPKR' environment variable")
-        env_speaker = env.get(env_spkr_name)
+        env_speaker = env.get(ENV_SPKR)
 
     if args.interactive:
         speaker_name = None
@@ -406,63 +410,7 @@ def main():
     exit(0)
 
 
-def interactive_loop(speaker_name, use_local_speaker_list=False, no_env=False):
-
-    # Is the speaker name set on the command line?
-    # Is the speaker name set in the environment?
-    speaker = None
-    if not speaker_name and not no_env:
-        speaker_name = env.get(env_spkr_name)
-    if speaker_name:
-        speaker = get_speaker(speaker_name, use_local_speaker_list)
-        if not speaker:
-            error_and_exit("Speaker '{}' not found".format(speaker_name))
-
-    print("Entering SoCo-CLI interactive mode")
-    logging.info("Entering interactive mode")
-    set_interactive()
-    while True:
-        if speaker_name and speaker:
-            command = input(
-                "Enter sonos action (0 to exit) [{}] > ".format(speaker.player_name)
-            )
-        else:
-            command = input("Enter sonos action (0 to exit) [] > ")
-        if command == "0" or command.lower().startswith("exit"):
-            logging.info("Exiting interactive mode")
-            return True
-
-        # Command processing
-        try:
-            args = shlex_split(command)
-
-            # Setting a speaker to operate on?
-            try:
-                if "speaker" == args[0] and "=" == args[1]:
-                    speaker_name = args[2]
-                    speaker = get_speaker(speaker_name, use_local_speaker_list)
-                    if not speaker:
-                        print("Error: Speaker not found")
-                        speaker_name = None
-                    continue
-            except IndexError:
-                speaker_name = None
-                continue
-
-            if not speaker_name:
-                speaker = get_speaker(args.pop(0), use_local_speaker_list)
-                if not speaker:
-                    print("Error: Speaker not found")
-                    continue
-            action = args.pop(0)
-            response = process_action(
-                speaker, action, args, use_local_speaker_list=use_local_speaker_list
-            )
-            if not response:
-                print("Error: Action '{}'".format(action))
-        except:
-            print("Error: Invalid command")
-
+2
 
 if __name__ == "__main__":
     main()
